/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */
import './index.scss';

$(document).ready(() => {
  //
  // PICKUP SETTINGS
  //
  toggleShowMap();
  $('input[name=BPOSTSHM_PICKUP_SELECTOR_MAP_ENABLED]').on('change', () => {
    toggleShowMap();
  });
  function toggleShowMap() {
    if ($('input[name=BPOSTSHM_PICKUP_SELECTOR_MAP_ENABLED]:checked').val()) {
      $('input[name^=BPOSTSHM_PICKUP_SELECTOR_GMAPS_API_KEY]').closest('.form-group').show();
    } else {
      $('input[name^=BPOSTSHM_PICKUP_SELECTOR_GMAPS_API_KEY]').closest('.form-group').hide();
    }
  }

  //
  // DELIVERY OPTIONS
  //
  $('#delivery_options .form-group .col-lg-offset-3').removeClass('col-lg-offset-3');
  $('#delivery_options .form-group .col-lg-4').removeClass('col-lg-4').addClass('col-lg-2');
  $('#delivery_options .form-group .col-lg-8').removeClass('col-lg-8').addClass('col-lg-10');
  $('#delivery_options .form-group').addClass('clear');

  toggleApplyBusinessOptions();
  function toggleApplyBusinessOptions() {
    let disabled = false;

    if ($('#bpostshm_value_business').prop('checked')) {
      $('#BPOSTSHM_DELIVERY_OPTIONS_HOME_INSURANCE option[value=insurance]').prop('selected', true);
      $('#BPOSTSHM_DELIVERY_OPTIONS_HOME_INSURANCE_FROM').val('0');
      $('#BPOSTSHM_DELIVERY_OPTIONS_HOME_2ND_PRESENTATION_ENABLED_on').prop('checked', true);
      $('#BPOSTSHM_DELIVERY_OPTIONS_HOME_2ND_PRESENTATION_FROM').val('0');
      disabled = true;
    }
    $('#BPOSTSHM_DELIVERY_OPTIONS_HOME_INSURANCE').prop('disabled', disabled);
    $('#BPOSTSHM_DELIVERY_OPTIONS_HOME_INSURANCE_FROM').prop('disabled', disabled);
    $('#BPOSTSHM_DELIVERY_OPTIONS_HOME_2ND_PRESENTATION_ENABLED_on').prop('disabled', disabled);
    $('#BPOSTSHM_DELIVERY_OPTIONS_HOME_2ND_PRESENTATION_ENABLED_off').prop('disabled', disabled);
    $('#BPOSTSHM_DELIVERY_OPTIONS_HOME_2ND_PRESENTATION_FROM').prop('disabled', disabled);
  }
  $('input[name=BPOSTSHM_DELIVERY_OPTIONS_HOME_BUSINESS]').on('change', () => {
    toggleApplyBusinessOptions();
    toggleSignatureOrInsurance();
  });

  toggleSignatureOrInsurance();
  $('#BPOSTSHM_DELIVERY_OPTIONS_HOME_INSURANCE').on('change', () => {
    toggleSignatureOrInsurance();
  });
  function toggleSignatureOrInsurance() {
    const value = $('#BPOSTSHM_DELIVERY_OPTIONS_HOME_INSURANCE').val();
    const insuranceSignature = $('#BPOSTSHM_DELIVERY_OPTIONS_HOME_INSURANCE').closest('.form-group')
    const signatureFrom = $('#BPOSTSHM_DELIVERY_OPTIONS_HOME_SIGNATURE_FROM').closest('.form-group');
    const insuranceFrom = $('#BPOSTSHM_DELIVERY_OPTIONS_HOME_INSURANCE_FROM').closest('.form-group');
    const signatureCost = $('#BPOSTSHM_DELIVERY_OPTIONS_HOME_SIGNATURE_COST').closest('.form-group');
    const insuranceCost = $('#BPOSTSHM_DELIVERY_OPTIONS_HOME_INSURANCE_COST').closest('.form-group');

    insuranceSignature.addClass('col-lg-4');
    insuranceSignature.find('.col-lg-2').removeClass('col-lg-2').addClass('col-lg-6');
    insuranceSignature.find('.col-lg-10').removeClass('col-lg-10').addClass('col-lg-6');
    signatureFrom.removeClass('clear');
    signatureFrom.addClass('col-lg-3');
    signatureFrom.find('.col-lg-2').removeClass('col-lg-2').addClass('col-lg-7');
    signatureFrom.find('.col-lg-10').removeClass('col-lg-10').addClass('col-lg-5');
    signatureCost.removeClass('clear');
    signatureCost.addClass('col-lg-3');
    signatureCost.find('.col-lg-2').removeClass('col-lg-2').addClass('col-lg-7');
    signatureCost.find('.col-lg-10').removeClass('col-lg-10').addClass('col-lg-5');
    insuranceFrom.removeClass('clear');
    insuranceFrom.addClass('col-lg-3');
    insuranceFrom.find('.col-lg-2').removeClass('col-lg-2').addClass('col-lg-7');
    insuranceFrom.find('.col-lg-10').removeClass('col-lg-10').addClass('col-lg-5');
    insuranceCost.removeClass('clear');
    insuranceCost.addClass('col-lg-3');
    insuranceCost.find('.col-lg-2').removeClass('col-lg-2').addClass('col-lg-7');
    insuranceCost.find('.col-lg-10').removeClass('col-lg-10').addClass('col-lg-5');

    if (value === 'insurance') {
      insuranceFrom.show();
      signatureFrom.hide();
      insuranceCost.show();
      signatureCost.hide();
    } else if (value === 'signature') {
      signatureFrom.show();
      insuranceFrom.hide();
      signatureCost.show();
      insuranceCost.hide();
    } else {
      signatureFrom.hide();
      insuranceFrom.hide();
      signatureCost.hide();
      insuranceCost.hide();
    }
  }

  $('input[id$=SATURDAY_ENABLED_on], input[id$=INSURANCE_ENABLED_on], input[id$=PRESENTATION_ENABLED_on]').each(function () {
    const name = $(this).attr('name');
    toggleSaturdayOrInsuranceOptions(name, $(`input[name=${name}]:checked`).val());
  });
  $('input[name$=SATURDAY_ENABLED], input[name$=INSURANCE_ENABLED], input[name$=PRESENTATION_ENABLED]').on('change', function () {
    const name = $(this).attr('name');
    toggleSaturdayOrInsuranceOptions($(this).attr('name'), $(`input[name=${name}]:checked`).val());
  });
  function toggleSaturdayOrInsuranceOptions(name, value) {
    const enabled = $(`input[name=${name}]`).closest('.form-group');
    let from = name.replace('ENABLED', 'FROM');
    let cost = name.replace('ENABLED', 'COST');
    from = $(`input[name=${from}]`).closest('.form-group');
    cost = $(`input[name=${cost}]`).closest('.form-group');

    enabled.addClass('col-lg-4');
    enabled.find('.col-lg-2').removeClass('col-lg-2').addClass('col-lg-6');
    enabled.find('.col-lg-10').removeClass('col-lg-10').addClass('col-lg-6');
    from.removeClass('clear');
    from.addClass('col-lg-3');
    from.find('.col-lg-2').removeClass('col-lg-2').addClass('col-lg-7');
    from.find('.col-lg-10').removeClass('col-lg-10').addClass('col-lg-5');
    cost.removeClass('clear');
    cost.addClass('col-lg-3');
    cost.find('.col-lg-2').removeClass('col-lg-2').addClass('col-lg-7');
    cost.find('.col-lg-10').removeClass('col-lg-10').addClass('col-lg-5');

    if (value) {
      from.show();
      cost.show();
    } else {
      from.hide();
      cost.hide();
    }
  }

  //
  // DELIVERY SETTINGS
  //
  toggleDisplayDeliveryDate();
  $('input[name=BPOSTSHM_DELIVERY_DATE_ENABLED], input[name=BPOSTSHM_DELIVERY_DATE_CHOOSE]').on('change', () => {
    toggleDisplayDeliveryDate();
  });
  function toggleDisplayDeliveryDate() {
    if ($('input[name=BPOSTSHM_DELIVERY_DATE_ENABLED]:checked').val()) {
      $('input[name^=BPOSTSHM_DELIVERY_DATE_]').closest('.form-group').show();
      if ($('input[name=BPOSTSHM_DELIVERY_DATE_CHOOSE]:checked').val()) {
        $('input[name^=BPOSTSHM_DELIVERY_DATE_NUM_DATES_SHOWN]').closest('.form-group').show();
      } else {
        $('input[name^=BPOSTSHM_DELIVERY_DATE_NUM_DATES_SHOWN]').closest('.form-group').hide();
      }
    } else {
      $('input[name^=BPOSTSHM_DELIVERY_DATE_]').closest('.form-group').hide();
      $('input[name=BPOSTSHM_DELIVERY_DATE_ENABLED]').closest('.form-group').show();
    }
  }

  //
  // INTERNATIONAL SETTINGS
  //
  toggleHsCode();
  $('select[name=BPOSTSHM_INTL_HS_CODE_TYPE]').on('change', () => {
    toggleHsCode();
  });
  function toggleHsCode() {
    if ($('#BPOSTSHM_INTL_HS_CODE_TYPE').val() === 'fixed') {
      $('#BPOSTSHM_INTL_HS_CODE_FIXED_VALUE').closest('.form-group').show();
      $('#BPOSTSHM_INTL_HS_CODE_FEATURE_VALUE').closest('.form-group').hide();
    } else {
      $('#BPOSTSHM_INTL_HS_CODE_FIXED_VALUE').closest('.form-group').hide();
      $('#BPOSTSHM_INTL_HS_CODE_FEATURE_VALUE').closest('.form-group').show();
    }
  }

  toggleCountryOfOrigin();
  $('select[name=BPOSTSHM_INTL_COUNTRY_OF_ORIGIN_TYPE]').on('change', () => {
    toggleCountryOfOrigin();
  });
  function toggleCountryOfOrigin() {
    if ($('#BPOSTSHM_INTL_COUNTRY_OF_ORIGIN_TYPE').val() === 'fixed') {
      $('#BPOSTSHM_INTL_COUNTRY_OF_ORIGIN_FIXED_VALUE').closest('.form-group').show();
      $('#BPOSTSHM_INTL_COUNTRY_OF_ORIGIN_FEATURE_VALUE').closest('.form-group').hide();
    } else {
      $('#BPOSTSHM_INTL_COUNTRY_OF_ORIGIN_FIXED_VALUE').closest('.form-group').hide();
      $('#BPOSTSHM_INTL_COUNTRY_OF_ORIGIN_FEATURE_VALUE').closest('.form-group').show();
    }
  }

  toggleOutsideEU();
  $('input[name=BPOSTSHM_INTL_OUTSIDE_EU_ENABLED]').on('change', () => {
    toggleOutsideEU();
  });
  function toggleOutsideEU() {
    if ($('input[name=BPOSTSHM_INTL_OUTSIDE_EU_ENABLED]:checked').val()) {
      $('[id^=BPOSTSHM_INTL]').closest('.form-group').show();
      toggleHsCode();
      toggleCountryOfOrigin();
    } else {
      $('[id^=BPOSTSHM_INTL]').closest('.form-group').hide();
      $('input[name=BPOSTSHM_INTL_OUTSIDE_EU_ENABLED]').closest('.form-group').show();
    }
  }

  $('select[name=BPOSTSHM_INTL_HS_CODE_FEATURE_VALUE],select[name=BPOSTSHM_INTL_COUNTRY_OF_ORIGIN_FEATURE_VALUE]').on('change', function () {
    const $hsCodeValue = $('select[name=BPOSTSHM_INTL_HS_CODE_FEATURE_VALUE]');
    const $countryOfOriginValue = $('select[name=BPOSTSHM_INTL_COUNTRY_OF_ORIGIN_FEATURE_VALUE]');

    if ($hsCodeValue.val() === $countryOfOriginValue.val()) {
      if ($(this).attr('name') === $hsCodeValue.attr('name')) {
        $countryOfOriginValue.find('option').each(function () {
          if ($(this).val() && $(this).val() !== $hsCodeValue.val()) {
            $(this).prop('selected', true);
          }
        });
      } else {
        $hsCodeValue.find('option').each(function () {
          if ($(this).val() && $(this).val() !== $countryOfOriginValue.val()) {
            $(this).prop('selected', true);
          }
        });
      }
    }
  });

  //
  // LABELS SETTINGS
  //
  toggleUsePsLabels();
  $('input[name=BPOSTSHM_LABELS_USE_PS]').on('change', () => {
    toggleUsePsLabels();
  });
  function toggleUsePsLabels() {
    if ($('input[name=BPOSTSHM_LABELS_USE_PS]:checked').val()) {
      $('[id^=BPOSTSHM_LABELS_],input[name^=BPOSTSHM_LABELS_],.cron').closest('.form-group').show();
    } else {
      $('[id^=BPOSTSHM_LABELS_],input[name^=BPOSTSHM_LABELS_],.cron').closest('.form-group').hide();
      $('input[name=BPOSTSHM_LABELS_USE_PS]').closest('.form-group').show();
    }
  }
});
