/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

export default class DeliveryDateSelector {
  constructor(select, selectors, ajaxUrl) {
    this.select = $(select);
    this.selectors = selectors;
    this.parent = this.select.closest(selectors.deliveryDate);
    this.idCarrier = this.parent.closest(selectors.bpostshmCarrier).data('carrier-id');
    this.ajaxUrl = ajaxUrl;
  }

  /**
   * Loading Start
   */
  loadingStart() {
    this.parent.addClass('bpostshm-loading-date');
  }

  /**
   * Loading Finish
   */
  loadingFinish() {
    this.parent.removeClass('bpostshm-loading-date');
  }

  /**
   * Show an error message about delivery date
   * @param msg
   */
  showError(msg) {
    this.parent.find(this.selectors.alert)
      .text(msg)
      .show();
  }

  /**
   * Hide error message
   */
  hideError() {
    this.parent.find(this.selectors.alert)
      .hide();
  }

  /**
   * Save delivery date in DB
   */
  saveDeliveryDate() {
    const $this = this;
    const prevValue = this.select.data('prev-value');

    this.loadingStart();

    $(this.selectors.deliverySaturdayAlert).hide();

    $.ajax({
      type: 'POST',
      dataType: 'json',
      url: this.ajaxUrl,
      data: {
        ajax: 1,
        action: 'saveDeliveryDate',
        date: this.select.val(),
        idCarrier: this.idCarrier,
      },
    }).done((data) => {
      $this.hideError();
      if (data.errorMsg) {
        $this.showError(data.errorMsg);
        $this.select.find(`option[value=${prevValue}]`).prop('selected', 'selected');
      } else {
        $(`${$this.selectors.deliveryDate}`).data('prev-value', $this.select.val());
        $(`${$this.selectors.deliveryDate} option[value=${$this.select.val()}]`).prop('selected', 'selected');
        if (data.deliveryOptions) {
          const selector = this.selectors.deliveryOption;
          Object.keys(data.deliveryOptions).forEach((key) => {
            // update shipping costs
            $(`${selector} input[value="${key}"]`)
              .closest(selector)
              .find('.carrier-price')
              .html(data.deliveryOptions[key].price);
          });
        }
        if (data.isSaturday) {
          $(this.selectors.deliverySaturdayAlert).show();
        }
      }

      $this.loadingFinish();

      prestashop.emit('BpostshmDeliveryDateUpdated', {
        selector: $this,
        data,
      });
    });
  }
}
