/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

export default class Map {
  constructor(pickupSelector, idMap, showPopupMarker) {
    this.pickupSelector = pickupSelector;
    this.idMap = idMap;
    this.$map = $(`#${idMap}`);
    this.showPopupMarker = showPopupMarker;
    this.map = null;
    // eslint-disable-next-line no-undef
    this.config = bpostshm;
    this.markers = {};
  }

  /**
   * Load and show map with markers
   */
  initMap(pickups) {
    if (!document.getElementById(this.idMap)) {
      return false;
    }

    if (!Object.keys(pickups).length) {
      this.hide();
      return false;
    }

    this.show();

    return true;
  }

  /**
   * Fit map bounds
   */
  fitMapBounds() { }

  /**
   * Open popup marker for pickup and scroll to map
   * @param string ID pickup
   */
  // eslint-disable-next-line no-unused-vars
  openMapPopupMarker(id) {
    if (this.$map.length) {
      $('html, body').animate({
        scrollTop: this.$map.offset().top,
      }, 'slow');
    }
  }

  /**
   * Highlight marker for pickup
   * @param string ID pickup
   */
  // eslint-disable-next-line no-unused-vars
  dancingWithMarker(id) { }

  /**
   * Show map
   */
  show() {
    this.$map.show();
  }

  /**
   * Hide map
   */
  hide() {
    this.$map.hide();
  }

  /**
   * Genrerate popup content
   * @param pickup
   */
  getInfoWindowContent(pickup) {
    if (pickup.openingHoursHtml === undefined) {
      // eslint-disable-next-line no-param-reassign
      pickup = this.pickupSelector.applyPickupDetails(pickup.id);
    }
    let popup = `
      <div class="pickup-point">
        <h5>${pickup.name}</h5>
        <p>
          ${pickup.address}<br>
          ${pickup.postcode} ${pickup.city}
        </p>`;

    if (pickup.openingHoursHtml) {
      popup += `
        <h5>${this.config.trans.schedulesTitle}</h5>
        ${pickup.openingHoursHtml} `;
    }
    popup += `
        <p>${pickup.selectBtnHtml}</p>
      </div>`;
    return popup;
  }
}
