/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */
import PickupSelector from './PickupSelector';
import DeliveryDateSelector from './DeliveryDateSelector';

$(document).ready(() => {
  // eslint-disable-next-line no-undef
  const config = bpostshm;

  function getSelectedCarriers() {
    return String($("input[name^='delivery_option']:checked").val())
      .replaceAll(/\s+|undefined/g, '')
      .replace(/^,/g, '')
      .replace(/,$/g, '')
      .split(',');
  }

  function configureParcelLockerForm(bpostshmCarrier) {
    // Parcel Locker Form
    ['email'].forEach((name) => {
      const $requiredParcelLockerInput = bpostshmCarrier.find(`[name=bpostshm-${name}]`);

      if ($requiredParcelLockerInput.length) {
        $requiredParcelLockerInput.attr('required', 'required');
      } else {
        $(`[name=bpostshm-${name}]`).removeAttr('required');
      }
    });
  }

  const bpostshmCarriers = [];
  const pickupCarriers = [];

  $(config.selectors.bpostshmCarrier).each(function () {
    if ($(this).hasClass(config.selectors.pickupCarrier.replace('.', ''))) {
      // is pickup
      const pickupSelector = new PickupSelector(
        this,
        config.pickupAjaxUrl,
        config.design === 'inline',
        config.availableCountries[$(this).data('carrier-type')],
        config.defaultCountry,
      );
      pickupCarriers[pickupSelector.idCarrier] = pickupSelector;
      if (getSelectedPickupSelector(pickupSelector.idCarrier)) {
        if (pickupSelector.getSelectedPickup()) {
          pickupSelector.show();
        } else {
          pickupSelector.open();
        }
        configureParcelLockerForm(pickupSelector.carrierExtraContent);
      }
    } else {
      // basic bpostshm carrier
      bpostshmCarriers[$(this).data('carrier-id')] = $(this);
      if (getSelectedBpostshmCarrier($(this).data('carrier-id'))) {
        $(this).show();
      }
    }
  });

  function getSelectedBpostshmCarrier(search) {
    let bpostshmCarrier = null;
    getSelectedCarriers().forEach((idCarrier) => {
      if ((!search || parseInt(search, 10) === parseInt(idCarrier, 10))
          && bpostshmCarriers[idCarrier] !== undefined) {
        bpostshmCarrier = bpostshmCarriers[idCarrier];
      }
    });
    return bpostshmCarrier;
  }

  $(document).on('change', '.js-delivery-option input[type=radio]', () => {
    const bpostshmCarrier = getSelectedBpostshmCarrier();

    if (bpostshmCarrier) {
      bpostshmCarrier.show();
      configureParcelLockerForm(bpostshmCarrier);
    }
  });

  //
  // Delivery date part
  //
  $(document).on('change', `${config.selectors.deliveryDate} select`, function () {
    const deliveryDateSelector = new DeliveryDateSelector(
      this,
      config.selectors,
      config.deliveryDateAjaxUrl,
    );
    deliveryDateSelector.saveDeliveryDate();
    if (config.design === 'inline') {
      const pickupSelector = getSelectedPickupSelector();

      if (pickupSelector) {
        pickupSelector.open();
      }
    }
  });

  prestashop.on('bpostshmPickupUpdated', (event) => {
    if (event.pickup.country === 'BE') {
      event.selector.carrierExtraContent.find(`${config.selectors.deliveryDate}`).show();
    } else {
      event.selector.carrierExtraContent.find(`${config.selectors.deliveryDate}`).hide();
    }
    // modal design
    if (config.design === 'modal') {
      $(config.selectors.choosePickupBtn).hide();
    }
  });

  //
  // Pickup events
  //
  function getSelectedPickupSelector(search) {
    let selector = null;
    getSelectedCarriers().forEach((idCarrier) => {
      if ((!search || parseInt(search, 10) === parseInt(idCarrier, 10))
            && pickupCarriers[idCarrier] !== undefined) {
        selector = pickupCarriers[idCarrier];
      }
    });
    return selector;
  }

  $(document).on('change', '.js-delivery-option input[type=radio]', () => {
    const pickupSelector = getSelectedPickupSelector();

    if (pickupSelector) {
      pickupSelector.open();
      configureParcelLockerForm(pickupSelector.carrierExtraContent);
    }
  });

  $(document).on('click', config.selectors.changePickupBtn, () => {
    const pickupSelector = getSelectedPickupSelector();

    if (pickupSelector) {
      pickupSelector.open();
    }
  });

  prestashop.on('updatedCart', () => {
    const pickupMap = getSelectedPickupSelector();

    if (pickupMap) {
      pickupMap.open();
    }
  });

  // When we show popup marker
  $(document).on('change', 'input[name="bpostshm_pickup"]', () => {
    const pickupSelector = getSelectedPickupSelector();

    if (pickupSelector) {
      const id = $('input[name="bpostshm_pickup"]:checked').val();

      if (pickupSelector.map) {
        pickupSelector.map.openMapPopupMarker(id);
      } else {
        pickupSelector.selectPickup(id, true);
      }
    }
  });
  //

  // when we don't show popup marker
  $(document).on('click', `${config.selectors.pickupWidget.pickupList} .pickup-point`, function () {
    const pickupSelector = getSelectedPickupSelector();

    if (pickupSelector) {
      const id = $(this).data('pickup-id');
      pickupSelector.selectPickupInList(id);
      if (pickupSelector.map) {
        pickupSelector.map.dancingWithMarker(id);
      }
    }
  });
  //

  $(document).on('click', config.selectors.pickupWidget.markerBtn, function (e) {
    e.preventDefault();
    e.stopPropagation();
    const pickupSelector = getSelectedPickupSelector();

    if (pickupSelector) {
      const id = $(this).data('id');
      pickupSelector.selectPickup(id);
    }
  });

  $(document).on('click', config.selectors.pickupWidget.search.btn, (e) => {
    e.preventDefault();
    e.stopPropagation();
    const pickupSelector = getSelectedPickupSelector();

    if (pickupSelector) {
      pickupSelector.open();
    }
  });

  const keySelectors = `${config.selectors.pickupWidget.search.address},${config.selectors.pickupWidget.search.city},${config.selectors.pickupWidget.search.postcode}`;
  $(document).on('keypress keydown keyup', keySelectors, (e) => {
    const pickupSelector = getSelectedPickupSelector();

    if (pickupSelector) {
      if (e.which === 13) {
        e.preventDefault();
        e.stopPropagation();
        pickupSelector.open();
      }
    }
  });

  $('.bpostshm-tooltip[data-toggle="tooltip"]').tooltip();
});
