<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

use PrestaShop\Module\BpostShm\Service\DeliveryDateService;
use PrestaShop\PrestaShop\Adapter\Product\PriceFormatter;

/**
 * Class BpostshmDeliveryDateModuleFrontController
 */
class BpostshmDeliveryDateModuleFrontController extends ModuleFrontController
{
    /**
     * Displays and saves the delivery date during an AJAX request.
     *
     * @return void
     */
    public function displayAjaxSaveDeliveryDate()
    {
        /** @var DeliveryDateService $deliveryDateService */
        $deliveryDateService = $this->module->get('bpostshm.delivery_date_service');
        $errorMsg = '';
        $isSaturday = false;
        $deliveryOptions = null;
        try {
            $deliveryDate = Tools::getValue('date');
            if (!Validate::isLoadedObject($this->context->cart)) {
                throw new PrestaShopException($this->translator->trans('Cart not set yet!', [], 'Modules.Bpostshm.Admin'));
            }

            $idCarrier = $this->context->cart->id_carrier ?: (int) Tools::getValue('idCarrier');
            $dates = $deliveryDateService->getDeliveryDates($idCarrier, $this->context->cart);
            $found = false;
            foreach ($dates as $date) {
                if ($date == $deliveryDate) {
                    $found = true;
                    $isSaturday = $deliveryDateService->isSaturday($deliveryDate);
                    break;
                }
            }

            if ($found) {
                $deliveryDateService->setDeliveryDate($this->context->cart->id, $idCarrier, $deliveryDate);

                // new shipping costs
                Cache::clean('getPackageShippingCost_*');
                Cache::clean('Carrier::*');
                $this->context->cart->getDeliveryOptionList(null, true); // flush list
                $deliveryOptionsFinder = new DeliveryOptionsFinder(
                    $this->context,
                    $this->getTranslator(),
                    $this->objectPresenter,
                    new PriceFormatter()
                );
                $deliveryOptions = $deliveryOptionsFinder->getDeliveryOptions();
            } else {
                throw new PrestaShopException($this->translator->trans('You can not choose this date: "%date%".', ['%date%' => Tools::displayDate($deliveryDate)], 'Modules.Bpostshm.Admin'));
            }
        } catch (Exception $e) {
            $this->module->log($e->getMessage(), 2);
            $errorMsg = $e->getMessage();
        }

        $this->ajaxRender(json_encode([
            'errorMsg' => $errorMsg,
            'deliveryOptions' => $deliveryOptions,
            'isSaturday' => $isSaturday,
        ]));
    }
}
