<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Adapter\BpostshmOrder\CommandHandler;

use PrestaShop\Module\BpostShm\Adapter\BpostshmOrder\Command\CancelOrderCommand;
use PrestaShop\Module\BpostShm\Domain\BpostshmOrder\Exception\CancelStatusNotFoundException;
use PrestaShop\Module\BpostShm\Service\OrderService;
use PrestaShop\PrestaShop\Core\CommandBus\CommandBusInterface;
use PrestaShop\PrestaShop\Core\Domain\Order\Command\BulkChangeOrderStatusCommand;
use PrestaShop\PrestaShop\Core\Domain\Order\Exception\OrderException;

/**
 * @internal
 */
final class CancelOrderHandler implements CancelOrderHandlerInterface
{
    /**
     * @var OrderService
     */
    private $orderService;

    /**
     * @var CommandBusInterface
     */
    private $commandBus;

    /**
     * @param CommandBusInterface $commandBus
     * @param OrderService $orderService
     */
    public function __construct(CommandBusInterface $commandBus, OrderService $orderService)
    {
        $this->commandBus = $commandBus;
        $this->orderService = $orderService;
    }

    /**
     * @param CancelOrderCommand $command
     *
     * @throws OrderException
     * @throws CancelStatusNotFoundException
     */
    public function handle(CancelOrderCommand $command)
    {
        $statusId = $this->orderService->getCancelOrderStatusId();
        if (!$statusId) {
            throw new CancelStatusNotFoundException();
        }
        $this->commandBus->handle(new BulkChangeOrderStatusCommand(
            [$command->getOrderId()->getValue()],
            $statusId
        ));
    }
}
