<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Adapter\BpostshmOrder\CommandHandler;

use PrestaShop\Module\BpostShm\Adapter\BpostshmOrder\Command\PrepareMissingOrdersCommand;
use PrestaShop\Module\BpostShm\Domain\BpostshmOrder\Exception\PrepareMissingOrdersException;
use PrestaShop\Module\BpostShm\Domain\BpostshmOrder\ValueObject\Order;
use PrestaShop\Module\BpostShm\Service\OrderService;
use PrestaShop\PrestaShop\Core\Domain\Order\Exception\OrderException;
use PrestaShop\PrestaShop\Core\Domain\Order\ValueObject\OrderId;

/**
 * @internal
 */
final class PrepareMissingOrdersHandler implements PrepareMissingOrdersHandlerInterface
{
    /**
     * @var OrderService
     */
    private $orderService;

    /**
     * @param OrderService $orderService
     */
    public function __construct(OrderService $orderService)
    {
        $this->orderService = $orderService;
    }

    /**
     * @param PrepareMissingOrdersCommand $command
     *
     * @throws PrepareMissingOrdersException
     * @throws OrderException
     */
    public function handle(PrepareMissingOrdersCommand $command)
    {
        $ordersWithFailedToPrepare = [];
        $ordersWithPreparedIds = [];

        foreach ($command->getOrders() as $order) {
            try {
                $this->orderService->prepareBpostOrder($order, false);
                $ordersWithPreparedIds[] = $order->id;
            } catch (\Exception $e) {
                $ordersWithFailedToPrepare[] = new Order(new OrderId((int) $order->id), $e);
            }
        }

        if (!empty($ordersWithFailedToPrepare)) {
            throw new PrepareMissingOrdersException($ordersWithFailedToPrepare, $ordersWithPreparedIds);
        }
    }
}
