<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Adapter;

use PrestaShop\Module\BpostShm\Api\Bpost\Order\Customer\Receiver;
use PrestaShop\Module\BpostShm\Api\Bpost\Order\Customer\Sender;

/**
 * Class Parcel
 */
class Parcel
{
    /**
     * @var \Order
     */
    private $order;

    /**
     * @var string
     */
    private $deliveryMethod;

    /**
     * @var array
     */
    private $deliveryBoxOptions;

    /**
     * @var bool
     */
    private $isRetour;

    /**
     * @var Receiver
     */
    private $receiver;

    /**
     * @var Sender
     */
    private $sender;

    /**
     * @var bool
     */
    private $isIntl;

    /**
     * @var array
     */
    private $pickup;

    /**
     * @var string
     */
    private $mobile;

    /**
     * @var string
     */
    private $lang;

    /**
     * @var array
     */
    private $products = [];

    /**
     * @var float
     */
    private $value = 0;

    /**
     * @var int
     */
    private $weight = 0;

    /**
     * @param \Order $order
     * @param string $deliveryMethod
     * @param array $deliveryBoxOptions
     * @param bool $isRetour
     * @param Receiver $receiver
     * @param Sender $sender
     * @param bool $isIntl
     * @param array|null $pickup
     * @param string|null $mobile
     * @param string $lang
     */
    public function __construct(
        \Order $order,
        string $deliveryMethod,
        array $deliveryBoxOptions,
        bool $isRetour,
        Receiver $receiver,
        Sender $sender,
        bool $isIntl,
        ?array $pickup,
        ?string $mobile,
        string $lang
    ) {
        $this->order = $order;
        $this->deliveryMethod = $deliveryMethod;
        $this->deliveryBoxOptions = $deliveryBoxOptions;
        $this->isRetour = $isRetour;
        $this->receiver = $receiver;
        $this->sender = $sender;
        $this->isIntl = $isIntl;
        $this->pickup = $pickup;
        $this->mobile = $mobile;
        $this->lang = $lang;
    }

    /**
     * @return \Order
     */
    public function getOrder(): \Order
    {
        return $this->order;
    }

    /**
     * @return string
     */
    public function getDeliveryMethod(): string
    {
        return $this->deliveryMethod;
    }

    /**
     * @return array
     */
    public function getDeliveryBoxOptions(): array
    {
        return $this->deliveryBoxOptions;
    }

    /**
     * @return bool
     */
    public function isRetour(): bool
    {
        return $this->isRetour;
    }

    /**
     * @return Receiver
     */
    public function getReceiver(): Receiver
    {
        return $this->receiver;
    }

    /**
     * @return Sender
     */
    public function getSender(): Sender
    {
        return $this->sender;
    }

    /**
     * @return bool
     */
    public function isIntl(): bool
    {
        return $this->isIntl;
    }

    /**
     * @return array
     */
    public function getPickup(): ?array
    {
        return $this->pickup;
    }

    /**
     * @return string
     */
    public function getMobile(): string
    {
        return $this->mobile;
    }

    /**
     * @return string
     */
    public function getLang(): string
    {
        return $this->lang;
    }

    /**
     * @return array
     */
    public function getProducts(): array
    {
        return $this->products;
    }

    /**
     * @param [] $products
     */
    public function addProduct($product): void
    {
        $this->products[] = $product;
        $this->value += $product['value'];
        $this->weight += $product['weight'];
    }

    /**
     * @return float
     */
    public function getValue(): float
    {
        return $this->value;
    }

    /**
     * @return int
     */
    public function getWeight(): int
    {
        return $this->weight;
    }
}
