<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Adapter\Presenter\Order;

use PrestaShop\Module\BpostShm\Service\CarrierService;
use PrestaShop\Module\BpostShm\Service\LabelService;

class OrderDetailLazyArray extends \PrestaShop\PrestaShop\Adapter\Presenter\Order\OrderDetailLazyArray
{
    /** @var BpostShm */
    private $module;

    /** @var \Order */
    private $order;

    /**
     * OrderDetailLazyArray constructor.
     *
     * @param $module
     * @param \Order $order
     */
    public function __construct($module, \Order $order)
    {
        $this->module = $module;
        $this->order = $order;
        parent::__construct($order);
    }

    /**
     * @arrayAccess
     *
     * @inerhitDoc
     */
    public function getShipping(): array
    {
        /** @var CarrierService $carrierService */
        $carrierService = $this->module->get('bpostshm.carrier_service');

        /** @var LabelService $labelService */
        $labelService = $this->module->get('bpostshm.label_service');

        $shippingList = parent::getShipping();

        foreach ($shippingList as $shippingId => $shipping) {
            if (isset($shipping['carrier_name'])) {
                $shippingList[$shippingId]['carrier_name'] = $carrierService->getTranslatedCarrierName(
                    $shipping['carrier_name'],
                    $this->order->getAssociatedLanguage()
                );
            }
            if ($shippingList[$shippingId]['tracking']) {
                $shippingList[$shippingId]['tracking'] = '';
                $url = '';
                $trackings = $labelService->getTrackingNumbers($this->order->id);
                foreach ($trackings as $tracking) {
                    if ($tracking['url']) {
                        if (!$url) {
                            $url = $tracking['url'];
                        }
                        if ($shippingList[$shippingId]['tracking']) {
                            $shippingList[$shippingId]['tracking'] .= ', ';
                        }
                        $shippingList[$shippingId]['tracking'] .= '<a href="' . $tracking['url'] . '" target="_blank">'
                            . $tracking['number'] . '</a>';
                    }
                }
                if ($url) {
                    $shippingList[$shippingId]['url'] = $url;
                }
            }
        }

        return $shippingList;
    }
}
