<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Api\ApiCaller;

use PrestaShop\Module\BpostShm\Api\Exception\BpostApiResponseException;
use PrestaShop\Module\BpostShm\Api\Exception\BpostApiResponseException\BpostApiBusinessException;
use PrestaShop\Module\BpostShm\Api\Exception\BpostApiResponseException\BpostApiSystemException;
use PrestaShop\Module\BpostShm\Api\Exception\BpostApiResponseException\BpostCurlException;
use PrestaShop\Module\BpostShm\Api\Exception\BpostApiResponseException\BpostInvalidResponseException;
use PrestaShop\Module\BpostShm\Api\Exception\BpostApiResponseException\BpostInvalidXmlResponseException;

class ApiCaller
{
    /** @var int */
    private $responseHttpCode;

    /** @var string */
    private $responseBody;

    /** @var string */
    private $responseContentType;

    /**
     * @return int
     */
    public function getResponseHttpCode()
    {
        return $this->responseHttpCode;
    }

    /**
     * @return string
     */
    public function getResponseBody()
    {
        return $this->responseBody;
    }

    /**
     * @return string
     */
    public function getResponseContentType()
    {
        return $this->responseContentType;
    }

    /**
     * @param array $options
     *
     * @return bool
     *
     * @throws BpostApiBusinessException
     * @throws BpostApiResponseException
     * @throws BpostApiSystemException
     * @throws BpostCurlException
     * @throws BpostInvalidResponseException
     * @throws BpostInvalidXmlResponseException
     */
    public function doCall(array $options)
    {
        $curl = curl_init();

        // set options
        curl_setopt_array($curl, $options);

        // execute
        $this->responseBody = curl_exec($curl);
        $errorNumber = curl_errno($curl);
        $errorMessage = curl_error($curl);

        $headers = curl_getinfo($curl);

        // error?
        if ($errorNumber !== 0) {
            throw new BpostCurlException($errorMessage, $errorNumber);
        }

        if (isset($headers['http_code'])) {
            $this->responseHttpCode = $headers['http_code'];
        }

        if (isset($headers['Content-Type'])) {
            $this->responseContentType = $headers['Content-Type'];
        }

        return true;
    }

    /**
     * If the httpCode is 200, return 200
     * If the httpCode is 203, return 200
     * If the httpCode is 404 ,return 404
     * ...
     *
     * @return int
     */
    public function getHttpCodeType()
    {
        return 100 * (int) ($this->responseHttpCode / 100);
    }
}
