<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Api\Bpost;

use PrestaShop\Module\BpostShm\Api\Common\ValidatedValue\LabelFormat;

/**
 * Class CreateLabelInBulkForOrders
 */
class CreateLabelInBulkForOrders
{
    /**
     * @param string[] $references
     *
     * @return string
     */
    public function getXml(array $references)
    {
        $document = new \DOMDocument('1.0', 'UTF-8');
        $document->preserveWhiteSpace = false;
        $document->formatOutput = true;

        $batchLabels = $document->createElement('batchLabels');
        $batchLabels->setAttribute('xmlns', 'http://schema.post.be/shm/deepintegration/v3/');
        foreach ($references as $reference) {
            $batchLabels->appendChild(
                $document->createElement('order', $reference)
            );
        }
        $document->appendChild($batchLabels);

        return $document->saveXML();
    }

    /**
     * @param bool $asPdf
     *
     * @return string[]
     */
    public function getHeaders($asPdf)
    {
        return [
            'Accept: application/vnd.bpost.shm-label-' . ($asPdf ? 'pdf' : 'image') . '-v3+XML',
            'Content-Type: application/vnd.bpost.shm-labelRequest-v3+XML',
        ];
    }

    /**
     * @param LabelFormat $format
     * @param bool $withReturnLabels
     * @param bool $forcePrinting
     *
     * @return string
     */
    public function getUrl(LabelFormat $format, $withReturnLabels, $forcePrinting = false)
    {
        return '/labels/' . $format->getValue()
               . ($withReturnLabels ? '/withReturnLabels' : '')
               . ($forcePrinting ? '?forcePrinting=true' : '');
    }
}
