<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Api\Bpost\Order\Box;

use PrestaShop\Module\BpostShm\Api\Bpost\Order\Address\ParcelsDepotAddress;
use PrestaShop\Module\BpostShm\Api\Bpost\Order\Box\National\Unregistered;
use PrestaShop\Module\BpostShm\Api\Bpost\Order\Box\Option\Messaging;
use PrestaShop\Module\BpostShm\Api\Bpost\ProductConfiguration\Product;
use PrestaShop\Module\BpostShm\Api\Exception\BpostLogicException\BpostInvalidLengthException;
use PrestaShop\Module\BpostShm\Api\Exception\BpostLogicException\BpostInvalidValueException;
use PrestaShop\Module\BpostShm\Api\Exception\BpostNotImplementedException;
use PrestaShop\Module\BpostShm\Api\Exception\XmlException\BpostXmlInvalidItemException;

class At247 extends National
{
    /** @var string */
    private $parcelsDepotId;

    /** @var string */
    private $parcelsDepotName;

    /** @var ParcelsDepotAddress */
    private $parcelsDepotAddress;

    /** @var string */
    protected $product = Product::PRODUCT_NAME_BPACK_24H_PRO;

    /** @var string */
    private $memberId;

    /** @var Unregistered */
    private $unregistered;

    /** @var string */
    private $receiverName;

    /** @var string */
    private $receiverCompany;

    /** @var string */
    protected $requestedDeliveryDate;

    /**
     * @param string $memberId
     */
    public function setMemberId($memberId)
    {
        $this->memberId = $memberId;
    }

    /**
     * @return string
     */
    public function getMemberId()
    {
        return $this->memberId;
    }

    /**
     * @param ParcelsDepotAddress $parcelsDepotAddress
     */
    public function setParcelsDepotAddress($parcelsDepotAddress)
    {
        $this->parcelsDepotAddress = $parcelsDepotAddress;
    }

    /**
     * @return ParcelsDepotAddress
     */
    public function getParcelsDepotAddress()
    {
        return $this->parcelsDepotAddress;
    }

    /**
     * @param string $parcelsDepotId
     */
    public function setParcelsDepotId($parcelsDepotId)
    {
        $this->parcelsDepotId = $parcelsDepotId;
    }

    /**
     * @return string
     */
    public function getParcelsDepotId()
    {
        return $this->parcelsDepotId;
    }

    /**
     * @param string $parcelsDepotName
     */
    public function setParcelsDepotName($parcelsDepotName)
    {
        $this->parcelsDepotName = $parcelsDepotName;
    }

    /**
     * @return string
     */
    public function getParcelsDepotName()
    {
        return $this->parcelsDepotName;
    }

    /**
     * @return Unregistered
     */
    public function getUnregistered()
    {
        return $this->unregistered;
    }

    /**
     * @param Unregistered $unregistered
     */
    public function setUnregistered(Unregistered $unregistered)
    {
        $this->unregistered = $unregistered;
    }

    /**
     * @param string $product Possible values are: bpack 24h Pro
     *
     * @throws BpostInvalidValueException
     */
    public function setProduct($product)
    {
        if (!in_array($product, self::getPossibleProductValues())) {
            throw new BpostInvalidValueException('product', $product, self::getPossibleProductValues());
        }

        parent::setProduct($product);
    }

    /**
     * @return array
     */
    public static function getPossibleProductValues()
    {
        return [
            Product::PRODUCT_NAME_BPACK_24H_PRO,
            Product::PRODUCT_NAME_BPACK_24_7,
        ];
    }

    /**
     * @param string $receiverCompany
     */
    public function setReceiverCompany($receiverCompany)
    {
        $this->receiverCompany = $receiverCompany;
    }

    /**
     * @return string
     */
    public function getReceiverCompany()
    {
        return $this->receiverCompany;
    }

    /**
     * @param string $receiverName
     */
    public function setReceiverName($receiverName)
    {
        $this->receiverName = $receiverName;
    }

    /**
     * @return string
     */
    public function getReceiverName()
    {
        return $this->receiverName;
    }

    /**
     * @return string
     */
    public function getRequestedDeliveryDate()
    {
        return $this->requestedDeliveryDate;
    }

    /**
     * @param string $requestedDeliveryDate
     */
    public function setRequestedDeliveryDate($requestedDeliveryDate)
    {
        $this->requestedDeliveryDate = (string) $requestedDeliveryDate;
    }

    /**
     * Return the object as an array for usage in the XML
     *
     * @param \DOMDocument $document
     * @param string $prefix
     * @param string $type
     *
     * @return \DOMElement
     */
    public function toXML(\DOMDocument $document, $prefix = null, $type = null)
    {
        $tagName = 'nationalBox';
        if ($prefix !== null) {
            $tagName = $prefix . ':' . $tagName;
        }
        $nationalElement = $document->createElement($tagName);
        $boxElement = parent::toXML($document, null, 'at24-7');
        $nationalElement->appendChild($boxElement);

        if ($this->getParcelsDepotId() !== null) {
            $boxElement->appendChild(
                $document->createElement('parcelsDepotId', $this->getParcelsDepotId())
            );
        }
        if ($this->getParcelsDepotName() !== null) {
            $boxElement->appendChild(
                $document->createElement(
                    'parcelsDepotName',
                    $this->getParcelsDepotName()
                )
            );
        }
        if ($this->getParcelsDepotAddress() !== null) {
            $boxElement->appendChild(
                $this->getParcelsDepotAddress()->toXML($document)
            );
        }
        if ($this->getMemberId() !== null) {
            $boxElement->appendChild(
                $document->createElement(
                    'memberId',
                    $this->getMemberId()
                )
            );
        }
        $this->addToXmlUnregistered($document, $boxElement, $prefix);
        if ($this->getReceiverName() !== null) {
            $boxElement->appendChild(
                $document->createElement(
                    'receiverName',
                    $this->getReceiverName()
                )
            );
        }
        if ($this->getReceiverCompany() !== null) {
            $boxElement->appendChild(
                $document->createElement(
                    'receiverCompany',
                    $this->getReceiverCompany()
                )
            );
        }
        $this->addToXmlRequestedDeliveryDate($document, $boxElement, $prefix);

        return $nationalElement;
    }

    /**
     * @param \DOMDocument $document
     * @param \DOMElement $typeElement
     * @param string $prefix
     */
    protected function addToXmlRequestedDeliveryDate(\DOMDocument $document, \DOMElement $typeElement, $prefix)
    {
        if ($this->getRequestedDeliveryDate() !== null) {
            $typeElement->appendChild(
                $document->createElement(
                    $this->getPrefixedTagName('requestedDeliveryDate', $prefix),
                    $this->getRequestedDeliveryDate()
                )
            );
        }
    }

    /**
     * @param \DOMDocument $document
     * @param \DOMElement $typeElement
     * @param string $prefix
     */
    protected function addToXmlUnregistered(\DOMDocument $document, \DOMElement $typeElement, $prefix)
    {
        if ($this->getUnregistered() !== null) {
            $typeElement->appendChild(
                $this->getUnregistered()->toXml($document)
            );
        }
    }

    /**
     * @param \SimpleXMLElement $xml
     * @param National|null $self
     *
     * @return At247
     *
     * @throws BpostInvalidValueException
     * @throws BpostNotImplementedException
     * @throws BpostInvalidLengthException
     * @throws BpostXmlInvalidItemException
     */
    public static function createFromXML(\SimpleXMLElement $xml, ?National $self = null)
    {
        $at247 = new At247();

        if (isset($xml->{'at24-7'}->product) && $xml->{'at24-7'}->product != '') {
            $at247->setProduct(
                (string) $xml->{'at24-7'}->product
            );
        }
        if (isset($xml->{'at24-7'}->options)) {
            /** @var \SimpleXMLElement $optionData */
            foreach ($xml->{'at24-7'}->options as $optionData) {
                $optionData = $optionData->children('http://schema.post.be/shm/deepintegration/v3/common');

                if (in_array($optionData->getName(), [Messaging::MESSAGING_TYPE_INFO_DISTRIBUTED])) {
                    $option = Messaging::createFromXML($optionData);
                } else {
                    $option = self::getOptionFromOptionData($optionData);
                }

                $at247->addOption($option);
            }
        }
        if (isset($xml->{'at24-7'}->weight) && $xml->{'at24-7'}->weight != '') {
            $at247->setWeight(
                (int) $xml->{'at24-7'}->weight
            );
        }
        if (isset($xml->{'at24-7'}->memberId) && $xml->{'at24-7'}->memberId != '') {
            $at247->setMemberId(
                (string) $xml->{'at24-7'}->memberId
            );
        }
        if (isset($xml->{'at24-7'}->receiverName) && $xml->{'at24-7'}->receiverName != '') {
            $at247->setReceiverName(
                (string) $xml->{'at24-7'}->receiverName
            );
        }
        if (isset($xml->{'at24-7'}->receiverCompany) && $xml->{'at24-7'}->receiverCompany != '') {
            $at247->setReceiverCompany(
                (string) $xml->{'at24-7'}->receiverCompany
            );
        }
        if (isset($xml->{'at24-7'}->parcelsDepotId) && $xml->{'at24-7'}->parcelsDepotId != '') {
            $at247->setParcelsDepotId(
                (string) $xml->{'at24-7'}->parcelsDepotId
            );
        }
        if (isset($xml->{'at24-7'}->parcelsDepotName) && $xml->{'at24-7'}->parcelsDepotName != '') {
            $at247->setParcelsDepotName(
                (string) $xml->{'at24-7'}->parcelsDepotName
            );
        }
        if (isset($xml->{'at24-7'}->parcelsDepotAddress)) {
            /** @var \SimpleXMLElement $parcelsDepotAddressData */
            $parcelsDepotAddressData = $xml->{'at24-7'}->parcelsDepotAddress->children(
                'http://schema.post.be/shm/deepintegration/v3/common'
            );
            $at247->setParcelsDepotAddress(
                ParcelsDepotAddress::createFromXML($parcelsDepotAddressData)
            );
        }
        if (isset($xml->{'at24-7'}->requestedDeliveryDate) && $xml->{'at24-7'}->requestedDeliveryDate != '') {
            $at247->setRequestedDeliveryDate(
                (string) $xml->{'at24-7'}->requestedDeliveryDate
            );
        }

        return $at247;
    }
}
