<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Api\Bpost\Order\Box;

use PrestaShop\Module\BpostShm\Api\Exception\BpostLogicException\BpostInvalidLengthException;
use PrestaShop\Module\BpostShm\Api\Exception\BpostLogicException\BpostInvalidPatternException;

class AtIntlHome extends International
{
    const TAG_NAME = 'atIntlHome';

    /**
     * @var array
     */
    private $parcelContents;

    /**
     * @param array $parcelContents
     */
    public function setParcelContents($parcelContents)
    {
        $this->parcelContents = $parcelContents;
    }

    /**
     * @return array
     */
    public function getParcelContents()
    {
        return $this->parcelContents;
    }

    /**
     * @param ParcelContent $parcelContent
     */
    public function addParcelContent(ParcelContent $parcelContent)
    {
        $this->parcelContents[] = $parcelContent;
    }

    /**
     * Additional elements within descendants
     *
     * @param \DOMDocument $document
     * @param \DOMElement $element
     *
     * @throws \DOMException
     */
    protected function alsoToXML(\DOMDocument $document, \DOMElement $element)
    {
        $parcelContents = $this->getParcelContents();
        if (!empty($parcelContents)) {
            $parent = $document->createElement('international:parcelContents');
            foreach ($parcelContents as $content) {
                $parent->appendChild($content->toXML($document, 'international'));
            }
            $element->appendChild($parent);
        }
    }

    /**
     * @param \SimpleXMLElement $xml
     *
     * @throws BpostInvalidLengthException
     * @throws BpostInvalidPatternException
     */
    protected function createAlsoFromXML(\SimpleXMLElement $xml)
    {
        if (isset($xml->parcelContents)) {
            foreach ($xml->parcelContents as $parcelContent) {
                $this->addParcelContent(ParcelContent::createFromXML($parcelContent));
            }
        }
    }
}
