<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Api\Bpost\Order\Box;

use PrestaShop\Module\BpostShm\Api\Bpost\Order\Address\IntlPugoAddress;
use PrestaShop\Module\BpostShm\Api\Bpost\Order\Address\PugoAddress;
use PrestaShop\Module\BpostShm\Api\Bpost\ProductConfiguration\Product;
use PrestaShop\Module\BpostShm\Api\Exception\BpostLogicException\BpostInvalidLengthException;
use PrestaShop\Module\BpostShm\Api\Exception\BpostLogicException\BpostInvalidPatternException;

class AtIntlPugo extends International
{
    const TAG_NAME = 'atIntlPugo';

    /**
     * @var string
     */
    protected $product;

    /**
     * @var string
     */
    private $pugo_id;

    /**
     * @var string
     */
    private $pugo_name;

    /**
     * @var PugoAddress;
     */
    private $pugo_address;

    public function __construct()
    {
        $this->product = Product::PRODUCT_NAME_BPACK_AT_BPOST_WORLD;
    }

    /**
     * @param string $pugo_id
     */
    public function setPugoId($pugo_id)
    {
        $this->pugo_id = $pugo_id;
    }

    /**
     * @return string
     */
    public function getPugoId()
    {
        return $this->pugo_id;
    }

    /**
     * @param string $pugo_name
     */
    public function setPugoName($pugo_name)
    {
        $this->pugo_name = $pugo_name;
    }

    /**
     * @return string
     */
    public function getPugoName()
    {
        return $this->pugo_name;
    }

    /**
     * @param IntlPugoAddress $pugo_address
     */
    public function setPugoAddress($pugo_address)
    {
        $this->pugo_address = $pugo_address;
    }

    /**
     * @return IntlPugoAddress
     */
    public function getPugoAddress()
    {
        return $this->pugo_address;
    }

    public static function getPossibleProductValues()
    {
        return [
            Product::PRODUCT_NAME_BPACK_AT_BPOST_WORLD,
        ];
    }

    /**
     * Additional elements within descendants
     *
     * @param \DOMDocument $document
     * @param \DOMElement $element
     *
     * @return \DOMElement
     *
     * @throws \DOMException
     */
    protected function alsoToXML(\DOMDocument $document, \DOMElement $element)
    {
        if ($this->getPugoId() !== null) {
            $element->appendChild(
                $document->createElement(
                    'international:pugoId',
                    $this->getPugoId()
                )
            );
        }
        if ($this->getPugoName() !== null) {
            $element->appendChild(
                $document->createElement(
                    'international:pugoName',
                    $this->getPugoName()
                )
            );
        }
        if ($this->getPugoAddress() !== null) {
            $element->appendChild(
                $this->getPugoAddress()->toXML($document)
            );
        }
    }

    /**
     * @param \SimpleXMLElement $xml
     *
     * @return Derivative instance
     *
     * @throws BpostInvalidLengthException
     * @throws BpostInvalidPatternException
     */
    protected function createAlsoFromXML(\SimpleXMLElement $xml)
    {
        if (isset($xml->parcelContents)) {
            foreach ($xml->parcelContents as $parcelContent) {
                $this->addParcelContent(ParcelContent::createFromXML($parcelContent));
            }
        }
        if (isset($xml->pugoId) && $xml->pugoId != '') {
            $this->setPugoId((string) $xml->pugoId);
        }
        if (isset($xml->pugoName) && $xml->pugoName != '') {
            $this->setPugoName((string) $xml->pugoName);
        }
        if (isset($xml->pugoAddress)) {
            $data = $xml->pugoAddress->children(
                'http://schema.post.be/shm/deepintegration/v3/common'
            );
            $this->setPugoAddress(
                IntlPugoAddress::createFromXML($data)
            );
        }
    }
}
