<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Api\Bpost\Order\Box;

use PrestaShop\Module\BpostShm\Api\Bpost\Order\Customer\Receiver;
use PrestaShop\Module\BpostShm\Api\Exception\XmlException\BpostXmlInvalidItemException;

class BpostOnAppointment extends National
{
    /** @var Receiver */
    private $receiver;

    /** @var string */
    protected $inNetworkCutOff;

    /**
     * @param Receiver $receiver
     */
    public function setReceiver(Receiver $receiver)
    {
        $this->receiver = $receiver;
    }

    /**
     * @return Receiver
     */
    public function getReceiver()
    {
        return $this->receiver;
    }

    /**
     * @return string
     */
    public function getInNetworkCutOff()
    {
        return $this->inNetworkCutOff;
    }

    /**
     * @param string $inNetworkCutOff
     */
    public function setInNetworkCutOff($inNetworkCutOff)
    {
        $this->inNetworkCutOff = (string) $inNetworkCutOff;
    }

    /**
     * Return the object as an array for usage in the XML
     *
     * @param \DOMDocument $document
     * @param null $prefix
     * @param null $type
     *
     * @return \DOMElement
     *
     * @throws \DOMException
     */
    public function toXML(\DOMDocument $document, $prefix = null, $type = null)
    {
        $nationalElement = $document->createElement($this->getPrefixedTagName('nationalBox', $prefix));
        $boxElement = parent::toXML($document, null, 'bpostOnAppointment');
        $nationalElement->appendChild($boxElement);

        $this->addToXmlReceiver($document, $boxElement);

        $this->addToXmlRequestedDeliveryDate($document, $boxElement, $prefix);

        return $nationalElement;
    }

    /**
     * @param \DOMDocument $document
     * @param \DOMElement $typeElement
     */
    protected function addToXmlReceiver(\DOMDocument $document, \DOMElement $typeElement)
    {
        if ($this->getReceiver() !== null) {
            $typeElement->appendChild(
                $this->getReceiver()->toXML($document)
            );
        }
    }

    /**
     * @param \DOMDocument $document
     * @param \DOMElement $typeElement
     * @param string $prefix
     *
     * @throws \DOMException
     */
    protected function addToXmlRequestedDeliveryDate(\DOMDocument $document, \DOMElement $typeElement, $prefix)
    {
        if ($this->getInNetworkCutOff() !== null) {
            $typeElement->appendChild(
                $document->createElement(
                    $this->getPrefixedTagName('inNetworkCutOff', $prefix),
                    $this->getInNetworkCutOff()
                )
            );
        }
    }

    /**
     * @param \SimpleXMLElement $xml
     * @param National|null $self
     *
     * @return BpostOnAppointment
     *
     * @throws BpostXmlInvalidItemException
     */
    public static function createFromXML(\SimpleXMLElement $xml, ?National $self = null)
    {
        $self = new self();

        if (!isset($xml->bpostOnAppointment)) {
            throw new BpostXmlInvalidItemException("$xml->bpostOnAppointment doesn't exist");
        }

        $bpostOnAppointmentXml = $xml->bpostOnAppointment;

        if (isset($bpostOnAppointmentXml->receiver)) {
            $self->setReceiver(
                Receiver::createFromXML(
                    $bpostOnAppointmentXml->receiver->children('http://schema.post.be/shm/deepintegration/v3/common')
                )
            );
        }

        if (isset($bpostOnAppointmentXml->inNetworkCutOff) && $bpostOnAppointmentXml->inNetworkCutOff != '') {
            $self->setInNetworkCutOff(
                (string) $bpostOnAppointmentXml->inNetworkCutOff
            );
        }

        return $self;
    }
}
