<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Api\Bpost\Order\Box\OpeningHour;

use PrestaShop\Module\BpostShm\Api\Exception\BpostLogicException\BpostInvalidValueException;

class Day
{
    const DAY_MONDAY = 'Monday';
    const DAY_TUESDAY = 'Tuesday';
    const DAY_WEDNESDAY = 'Wednesday';
    const DAY_THURSDAY = 'Thursday';
    const DAY_FRIDAY = 'Friday';
    const DAY_SATURDAY = 'Saturday';
    const DAY_SUNDAY = 'Sunday';

    /**
     * @var string
     */
    private $day;

    /**
     * @var string
     */
    private $value;

    /**
     * @param string $day
     *
     * @throws BpostInvalidValueException
     */
    public function setDay($day)
    {
        if (!in_array($day, self::getPossibleDayValues())) {
            throw new BpostInvalidValueException('day', $day, self::getPossibleDayValues());
        }

        $this->day = $day;
    }

    /**
     * @return string
     */
    public function getDay()
    {
        return $this->day;
    }

    /**
     * @return array
     */
    public static function getPossibleDayValues()
    {
        return [
            self::DAY_MONDAY,
            self::DAY_TUESDAY,
            self::DAY_WEDNESDAY,
            self::DAY_THURSDAY,
            self::DAY_FRIDAY,
            self::DAY_SATURDAY,
            self::DAY_SUNDAY,
        ];
    }

    /**
     * @param string $value
     */
    public function setValue($value)
    {
        $this->value = $value;
    }

    /**
     * @return string
     */
    public function getValue()
    {
        return $this->value;
    }

    /**
     * @param string $day
     * @param string $value
     *
     * @throws BpostInvalidValueException
     */
    public function __construct($day, $value)
    {
        $this->setDay($day);
        $this->setValue($value);
    }

    /**
     * Return the object as an array for usage in the XML
     *
     * @param \DOMDocument $document
     * @param string $prefix
     *
     * @return \DOMElement
     */
    public function toXML(\DOMDocument $document, $prefix = null)
    {
        $tagName = $this->getDay();
        if ($prefix !== null) {
            $tagName = $prefix . ':' . $tagName;
        }

        return $document->createElement($tagName, $this->getValue());
    }
}
