<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Api\Bpost\Order\Box\Option;

class CashOnDelivery extends Option
{
    /**
     * @var float
     */
    private $amount;

    /**
     * @var string
     */
    private $iban;

    /**
     * @var string
     */
    private $bic;

    /**
     * @param float $amount
     */
    public function setAmount($amount)
    {
        $this->amount = $amount;
    }

    /**
     * @return float
     */
    public function getAmount()
    {
        return $this->amount;
    }

    /**
     * @param string $bic
     */
    public function setBic($bic)
    {
        $this->bic = $bic;
    }

    /**
     * @return string
     */
    public function getBic()
    {
        return $this->bic;
    }

    /**
     * @param string $iban
     */
    public function setIban($iban)
    {
        $this->iban = $iban;
    }

    /**
     * @return string
     */
    public function getIban()
    {
        return $this->iban;
    }

    /**
     * @param float $amount
     * @param string $iban
     * @param string $bic
     */
    public function __construct($amount, $iban, $bic)
    {
        $this->setAmount($amount);
        $this->setIban($iban);
        $this->setBic($bic);
    }

    /**
     * @inerhitDoc
     */
    public function toXML(\DOMDocument $document, $prefix = 'common')
    {
        $tagName = 'cod';
        if ($prefix !== null) {
            $tagName = $prefix . ':' . $tagName;
        }

        $cod = $document->createElement($tagName);

        if ($this->getAmount() !== null) {
            $tagName = 'codAmount';
            if ($prefix !== null) {
                $tagName = $prefix . ':' . $tagName;
            }
            $cod->appendChild(
                $document->createElement(
                    $tagName,
                    $this->getAmount()
                )
            );
        }
        if ($this->getIban() !== null) {
            $tagName = 'iban';
            if ($prefix !== null) {
                $tagName = $prefix . ':' . $tagName;
            }
            $cod->appendChild(
                $document->createElement(
                    $tagName,
                    $this->getIban()
                )
            );
        }
        if ($this->getBic() !== null) {
            $tagName = 'bic';
            if ($prefix !== null) {
                $tagName = $prefix . ':' . $tagName;
            }
            $cod->appendChild(
                $document->createElement(
                    $tagName,
                    $this->getBic()
                )
            );
        }

        return $cod;
    }
}
