<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Api\Bpost\Order;

use PrestaShop\Module\BpostShm\Api\Exception\BpostLogicException\BpostInvalidLengthException;

class Customer
{
    const TAG_NAME = 'customer';

    /**
     * @var string
     */
    private $name;

    /**
     * @var string
     */
    private $company;

    /**
     * @var Address
     */
    private $address;

    /**
     * @var string
     */
    private $emailAddress;

    /**
     * @var string
     */
    private $phoneNumber;

    /**
     * @param Address $address
     */
    public function setAddress($address)
    {
        $this->address = $address;
    }

    /**
     * @return Address
     */
    public function getAddress()
    {
        return $this->address;
    }

    /**
     * @param string $company
     */
    public function setCompany($company)
    {
        $this->company = $company;
    }

    /**
     * @return string
     */
    public function getCompany()
    {
        return $this->company;
    }

    /**
     * @param string $emailAddress
     *
     * @throws BpostInvalidLengthException
     */
    public function setEmailAddress($emailAddress)
    {
        $length = 50;
        if (mb_strlen($emailAddress) > $length) {
            throw new BpostInvalidLengthException('emailAddress', mb_strlen($emailAddress), $length);
        }
        $this->emailAddress = $emailAddress;
    }

    /**
     * @return string
     */
    public function getEmailAddress()
    {
        return $this->emailAddress;
    }

    /**
     * @param string $name
     */
    public function setName($name)
    {
        $this->name = $name;
    }

    /**
     * @return string
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * @param string $phoneNumber
     *
     * @throws BpostInvalidLengthException
     */
    public function setPhoneNumber($phoneNumber)
    {
        $length = 20;
        if (mb_strlen($phoneNumber) > $length) {
            throw new BpostInvalidLengthException('phoneNumber', mb_strlen($phoneNumber), $length);
        }
        $this->phoneNumber = $phoneNumber;
    }

    /**
     * @return string
     */
    public function getPhoneNumber()
    {
        return $this->phoneNumber;
    }

    /**
     * Return the object as an array for usage in the XML
     *
     * @param \DOMDocument $document
     * @param null $prefix
     *
     * @return \DOMElement
     *
     * @throws \DOMException
     */
    public function toXML(\DOMDocument $document, $prefix = null)
    {
        $tagName = static::TAG_NAME;
        if ($prefix !== null) {
            $tagName = $prefix . ':' . $tagName;
        }

        $customer = $document->createElement($tagName);

        if ($this->getName() !== null) {
            $customer->appendChild(
                $document->createElement(
                    'common:name',
                    $this->getName()
                )
            );
        }
        if ($this->getCompany() !== null) {
            $customer->appendChild(
                $document->createElement(
                    'common:company',
                    $this->getCompany()
                )
            );
        }
        if ($this->getAddress() !== null) {
            $customer->appendChild(
                $this->getAddress()->toXML($document)
            );
        }
        if ($this->getEmailAddress() !== null) {
            $customer->appendChild(
                $document->createElement(
                    'common:emailAddress',
                    $this->getEmailAddress()
                )
            );
        }
        if ($this->getPhoneNumber() !== null) {
            $customer->appendChild(
                $document->createElement(
                    'common:phoneNumber',
                    $this->getPhoneNumber()
                )
            );
        }

        return $customer;
    }

    /**
     * @param \SimpleXMLElement $xml
     * @param Customer $instance
     *
     * @return Customer
     *
     * @throws BpostInvalidLengthException
     */
    public static function createFromXMLHelper(\SimpleXMLElement $xml, Customer $instance)
    {
        if (isset($xml->name) && $xml->name != '') {
            $instance->setName((string) $xml->name);
        }
        if (isset($xml->company) && $xml->company != '') {
            $instance->setCompany((string) $xml->company);
        }
        if (isset($xml->address)) {
            $instance->setAddress(
                Address::createFromXML($xml->address)
            );
        }
        if (isset($xml->emailAddress) && $xml->emailAddress != '') {
            $instance->setEmailAddress(
                (string) $xml->emailAddress
            );
        }
        if (isset($xml->phoneNumber) && $xml->phoneNumber != '') {
            $instance->setPhoneNumber((string) $xml->phoneNumber);
        }

        return $instance;
    }
}
