<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Api\Bpost\Order;

class Line
{
    /**
     * @var string
     */
    private $text;

    /**
     * @var int
     */
    private $numberOfItems;

    /**
     * @param int $nbOfItems
     */
    public function setNumberOfItems($nbOfItems)
    {
        $this->numberOfItems = $nbOfItems;
    }

    /**
     * @return int
     */
    public function getNumberOfItems()
    {
        return $this->numberOfItems;
    }

    /**
     * @param string $text
     */
    public function setText($text)
    {
        $this->text = $text;
    }

    /**
     * @return string
     */
    public function getText()
    {
        return $this->text;
    }

    /**
     * @param string $text
     * @param int $numberOfItems
     */
    public function __construct($text = null, $numberOfItems = null)
    {
        if ($text != null) {
            $this->setText($text);
        }
        if ($numberOfItems != null) {
            $this->setNumberOfItems($numberOfItems);
        }
    }

    /**
     * Return the object as an array for usage in the XML
     *
     * @param \DOMDocument $document
     * @param null $prefix
     *
     * @return \DOMElement
     *
     * @throws \DOMException
     */
    public function toXML(\DOMDocument $document, $prefix = null)
    {
        $tagName = 'orderLine';
        if ($prefix !== null) {
            $tagName = $prefix . ':' . $tagName;
        }

        $line = $document->createElement($tagName);

        if ($this->getText() !== null) {
            $tagName = 'text';
            if ($prefix !== null) {
                $tagName = $prefix . ':' . $tagName;
            }
            $line->appendChild(
                $document->createElement(
                    $tagName,
                    $this->getText()
                )
            );
        }
        if ($this->getNumberOfItems() !== null) {
            $tagName = 'nbOfItems';
            if ($prefix !== null) {
                $tagName = $prefix . ':' . $tagName;
            }
            $line->appendChild(
                $document->createElement(
                    $tagName,
                    $this->getNumberOfItems()
                )
            );
        }

        return $line;
    }

    /**
     * @param \SimpleXMLElement $xml
     *
     * @return Line
     */
    public static function createFromXML(\SimpleXMLElement $xml)
    {
        $line = new Line();
        if (isset($xml->text) && '' !== $xml->text) {
            $line->setText((string) $xml->text);
        }
        if (isset($xml->nbOfItems) && '' !== $xml->nbOfItems) {
            $line->setNumberOfItems((int) $xml->nbOfItems);
        }

        return $line;
    }
}
