<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Command;

use PrestaShop\Module\BpostShm\Utils\Installer;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

/**
 * Class UpgradeToV2Command
 */
class UpgradeToV2Command extends Command
{
    /**
     * @var \BpostShm
     */
    private $module;

    /**
     * @var Db
     */
    private $database;

    /**
     * Constructor
     *
     * @param \BpostShm $module
     */
    public function __construct(\BpostShm $module)
    {
        $this->module = $module;
        $this->database = $module->getDatabase();
        parent::__construct('bpostshm:upgradeToV2');
    }

    protected function configure()
    {
        $this->setName('bpostshm:upgradeToV2')
            ->setDescription('Upgrade v1 bpost orders')
            ->addArgument(
                'max_date',
                InputArgument::OPTIONAL,
                'The maximum date in the past to consider when selecting orders (format: YYYY-MM-DD HH:MM:SS)',
                false
            )
        ;
    }

    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $io = new SymfonyStyle($input, $output);

        $error = false;
        $maxDate = $input->getArgument('max_date');
        if ($maxDate) {
            $maxTime = strtotime($maxDate);
            if ($maxTime === false) {
                $io->error("Max date ($maxDate) is invalid!");
                $error = true;
            }
            if ($maxTime > time()) {
                $io->error('Max date is in the future!');
                $error = true;
            }
        }

        $oldTables = [
            _DB_PREFIX_ . 'cart_bpost',
            _DB_PREFIX_ . 'order_bpost',
            _DB_PREFIX_ . 'order_bpost_label',
        ];
        foreach ($oldTables as $table) {
            $tableExists = (int) $this->database->getValue("
                SELECT COUNT(*)
                FROM information_schema.tables
                WHERE table_name = '$table'
            ") > 0;
            if (!$tableExists) {
                $io->error("Table '$table' not found in DB!");
                $error = true;
            } else {
                $nbRow = (int) $this->database->getValue("SELECT COUNT(*) FROM $table");
                $io->note("Table '$table' -> $nbRow row(s)");
            }
        }

        if ($error) {
            return 1;
        }

        (new Installer($this->module))->upgradeDataToV2($maxDate, $io);

        return 0;
    }
}
