<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Controller\Admin\Improve\Shipping;

use PrestaShop\Module\BpostShm\Grid\Definition\Factory\AbstractOrderGridDefinitionFactory;
use PrestaShop\Module\BpostShm\Search\Filters\TreatedOrderFilters;
use PrestaShopBundle\Security\Annotation\AdminSecurity;
use PrestaShopBundle\Service\Grid\ResponseBuilder;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * Manages "Improve > Shipping > bpost Shipping Manager"
 */
class TreatedOrderController extends OrderController
{
    /**
     * Show treated order listing page.
     *
     * @AdminSecurity("is_granted('read', request.get('_legacy_controller'))")
     *
     * @param Request $request
     * @param TreatedOrderFilters $treatedOrderFilters
     *
     * @return Response
     */
    public function indexAction(
        Request $request,
        TreatedOrderFilters $treatedOrderFilters
    ): Response {
        $treatedOrderGridFactory = $this->get('bpostshm.grid.factory.treated_order');
        $treatedOrderGrid = $treatedOrderGridFactory->getGrid($treatedOrderFilters);

        return $this->render('@Modules/bpostshm/views/PrestaShop/Admin/Improve/Shipping/TreatedOrder/index.html.twig', [
            'enableSidebar' => true,
            'help_link' => $this->generateSidebarLink($request->attributes->get('_legacy_controller')),
            'treatedOrderGrid' => $this->presentGrid($treatedOrderGrid),
        ]);
    }

    /**
     * Provides filters functionality
     *
     * @AdminSecurity("is_granted('read', request.get('_legacy_controller'))")
     *
     * @param Request $request
     *
     * @return RedirectResponse
     */
    public function searchAction(Request $request): RedirectResponse
    {
        $gridDefinitionFactory = 'bpostshm.grid.definition.factory.treated_order';
        $filterId = AbstractOrderGridDefinitionFactory::GRID_ID;
        if ($request->get('order') && !$request->get('bpost_order')) {
            $_POST[$filterId] = $_POST['order'];
            $request = Request::createFromGlobals();
        }

        /** @var ResponseBuilder $responseBuilder */
        $responseBuilder = $this->get('prestashop.bundle.grid.response_builder');

        return $responseBuilder->buildSearchResponse(
            $this->get($gridDefinitionFactory),
            $request,
            $filterId,
            'admin_bpostshm_treated_index'
        );
    }
}
