<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/OSL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/OSL-3.0 Open Software License (OSL 3.0)
 */

namespace PrestaShop\Module\BpostShm\Domain\BpostshmLabel\Exception;

use PrestaShop\Module\BpostShm\Domain\BpostshmOrder\Exception\OrderException;
use PrestaShop\Module\BpostShm\Domain\BpostshmOrder\ValueObject\Order;

/**
 * Throw when failed generating labels.
 */
class GenerateLabelsException extends OrderException
{
    /**
     * @var Order[]
     */
    private $ordersWithFailedToGenerateLabels;

    /**
     * @var int[]
     */
    private $ordersWithGeneratedLabelsIds;

    /**
     * Constructor
     *
     * @param Order[] $ordersWithFailedGenerateLabels
     * @param int[] $ordersWithGeneratedLabelsIdsOrderIds
     * @param string $message
     * @param int $code
     * @param \Exception|null $previous
     */
    public function __construct(
        array $ordersWithFailedGenerateLabels,
        array $ordersWithGeneratedLabelsIdsOrderIds,
        $message = '',
        int $code = 0,
        ?\Exception $previous = null
    ) {
        $this->ordersWithFailedToGenerateLabels = $ordersWithFailedGenerateLabels;
        $this->ordersWithGeneratedLabelsIds = $ordersWithGeneratedLabelsIdsOrderIds;

        parent::__construct($message, $code, $previous);
    }

    /**
     * @return Order[]
     */
    public function getOrdersWithFailedToGenerateLabels(): array
    {
        return $this->ordersWithFailedToGenerateLabels;
    }

    /**
     * @return int[]
     */
    public function getOrdersWithGeneratedLabelsIds(): array
    {
        return $this->ordersWithGeneratedLabelsIds;
    }
}
