<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

namespace PrestaShop\Module\BpostShm\Hook;

use BpostShm;
use PrestaShopBundle\Translation\TranslatorInterface;

/**
 * Class AbstractHook
 */
abstract class AbstractHook
{
    /**
     * List of available hooks for cron jobs.
     *
     * @var string[]
     */
    const AVAILABLE_HOOKS = [];

    /**
     * @var \Context
     */
    protected $context;

    /**
     * @var \BpostShm
     */
    protected $module;

    /**
     * @var \Db
     */
    protected $database;

    /**
     * @var TranslatorInterface
     */
    protected $translator;

    /**
     * Constructor
     *
     * @param \BpostShm $module the BpostShm object
     *
     * @return void
     */
    public function __construct(\BpostShm $module)
    {
        $this->module = $module;
        $this->context = $module->getContext();
        $this->database = $module->getDatabase();
        $this->translator = $module->getTranslator();
    }

    /**
     * Retrieves the available hooks.
     *
     * This method returns an array of available hooks that can be used in the application.
     *
     * @return array the array of available hooks
     */
    public function getAvailableHooks(): array
    {
        return static::AVAILABLE_HOOKS;
    }
}
