<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

namespace PrestaShop\Module\BpostShm\Hook;

use PrestaShop\Module\BpostShm\Service\PickupService;
use PrestaShop\Module\BpostShm\Utils\BpostTools;

/**
 * Class Email
 */
class Email extends AbstractHook
{
    const AVAILABLE_HOOKS = [
        'actionEmailSendBefore',
    ];

    /**
     * Performs actions before sending an email.
     *
     * @param array $params the parameters for the email
     *
     * @return bool returns true
     */
    public function actionEmailSendBefore(array $params): bool
    {
        $templateVars = $params['templateVars'];
        if (!isset($templateVars['{id_order}']) || $params['template'] != 'order_conf') {
            return true;
        }

        $order = new \Order($templateVars['{id_order}']);
        if (!\Validate::isLoadedObject($order)) {
            return true;
        }

        $idLang = $order->id_lang ?: $this->context->language->id;

        if (!$order->isVirtual()) {
            $carrier = new \Carrier($order->id_carrier);
            if (BpostTools::isBpostCarrier($carrier)) {
                /** @var PickupService $pickupService */
                $pickupService = $this->module->get('bpostshm.pickup_service');
                if ($pickupService->isPickup($carrier)) {
                    $address = $pickupService->getSelectedPickupAddress(
                        $carrier->id,
                        $idLang,
                        $order->id_cart,
                        true,
                        $params['templateVars']['{delivery_firstname}'],
                        $params['templateVars']['{delivery_lastname}']
                    );
                    $params['templateVars']['{delivery_block_txt}'] = \AddressFormat::generateAddress($address);
                    $params['templateVars']['{delivery_block_html}'] =
                        \AddressFormat::generateAddress(
                            $address,
                            ['avoid' => []],
                            '<br />',
                            ' ',
                            [
                                'firstname' => '<span style="font-weight:bold;">%s</span>',
                                'lastname' => '<span style="font-weight:bold;">%s</span>',
                            ]
                        );
                    $params['templateVars']['{delivery_alias}'] = $address->alias; // bonus
                    $params['templateVars']['{delivery_company}'] = $address->company;
                    $params['templateVars']['{delivery_address1}'] = $address->address1;
                    $params['templateVars']['{delivery_address2}'] = $address->address2;
                    $params['templateVars']['{delivery_city}'] = $address->city;
                    $params['templateVars']['{delivery_postal_code}'] = $address->postcode;
                    $params['templateVars']['{delivery_country}'] = $address->country;
                    $params['templateVars']['{delivery_state}'] = $address->id_state ? $address->name : '';
                    $params['templateVars']['{delivery_phone}'] = $address->phone ?: $address->phone_mobile;
                    $params['templateVars']['{delivery_other}'] = $address->other;
                }
            }
        }

        return true;
    }
}
