<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

namespace PrestaShop\Module\BpostShm\Hook;

use IntlDateFormatter;

/**
 * Class Smarty
 */
class Smarty extends AbstractHook
{
    /**
     * @inerhitDoc
     */
    const AVAILABLE_HOOKS = [
        'actionFrontControllerInitBefore',
    ];

    public function actionFrontControllerInitBefore()
    {
        $this->context->smarty->registerPlugin('modifier', 'intl_date_format', [$this, 'intlDateFormat']);
    }

    /**
     * Displays the date in the requested format, taking into account the current language.
     *
     * @param string $date a date/time string
     * @param string $format The date format used by IntlDateFormatter: FULL, LONG, MEDIUM, SHORT. Default is FULL
     *
     * @return string the date formatted with IntlDateFormatter according to given format
     *
     * @throws \Exception
     */
    public function intlDateFormat(string $date, string $format = 'full'): string
    {
        switch (\Tools::strtolower($format)) {
            case 'long':
                $format = \IntlDateFormatter::LONG;
                break;
            case 'medium':
                $format = \IntlDateFormatter::MEDIUM;
                break;
            case 'short':
                $format = \IntlDateFormatter::SHORT;
                break;
            case 'full':
            default:
                $format = \IntlDateFormatter::FULL;
                break;
        }
        $date = new \DateTime($date);
        $formatter = new \IntlDateFormatter(
            $this->context->language->locale,
            $format,
            \IntlDateFormatter::NONE
        );

        return $formatter->format($date);
    }
}
