<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

function upgrade_getNewDeliveryOptionListFrom($old_opt_string = '')
{
    if (empty($old_opt_string)) {
        return false;
    } elseif (false === strpos($old_opt_string, 'home')) {
        return $old_opt_string;
    }

    $old2new_tbl = [
        'home' => 1,
        'bpost' => 2,
        '247' => 4,
        'intl' => 9,
    ];
    $delivery_options = json_decode($old_opt_string, true);
    foreach ($delivery_options as $dm => $opt_string) {
        $keys = explode('|', $opt_string);
        $new_opt = [];
        foreach ($keys as $opt_key) {
            if (!empty($opt_key)) {
                $new_opt[$opt_key] = '0.0';
            }
        }
        $delivery_options[$old2new_tbl[$dm]] = $new_opt;
        unset($delivery_options[$dm]);
    }

    return json_encode($delivery_options, JSON_FORCE_OBJECT);
}

/**
 * @param $module
 *
 * @return bool
 */
function upgrade_module_1_22_0($module)
{
    $sql = 'ALTER TABLE `' . _DB_PREFIX_ . 'cart_bpost` ADD COLUMN `upl_info` TEXT AFTER `option_kmi`;';
    $ret = Db::getInstance()->execute($sql);

    Configuration::deleteByName('BPOST_HOME_DELIVERY_ONLY');

    // Translate BPOST_DELIVERY_OPTIONS_LIST
    // from {"home":"330|300","bpost":"","247":"350","intl":"540"}
    // to {"1":{"360":"1.2","470":["5.0","1.75"]},"2":{"300":"1.25"},"4":{},"9":{"540":"0.0"}}
    $sql = 'SELECT `id_configuration` as id, value
            FROM `' . _DB_PREFIX_ . 'configuration`
            WHERE `name` = "BPOST_DELIVERY_OPTIONS_LIST"
    ';
    if ($rows = Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS($sql)) {
        $ids = [];
        $sql = 'UPDATE `' . _DB_PREFIX_ . 'configuration`
                SET `value` = CASE';
        foreach ($rows as $row) {
            $sql .= 'WHEN `id_configuration` = ' . (int) $row['id'] . ' THEN "' . pSQL(upgrade_getNewDeliveryOptionListFrom($row['value'])) . '"';
            $ids[] = (int) $row['id'];
        }
        $sql .= '
                ELSE `value`
                END
                WHERE `id_configuration` IN (' . implode(',', $ids) . ')';

        $ret &= Db::getInstance()->execute($sql);
    }

    return (bool) $ret;
}
