<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

use PrestaShop\Module\BpostShm\Utils\FileUpgrader;

if (!defined('_PS_VERSION_')) {
    exit;
}

/**
 * @param $module
 *
 * @return bool
 */
function upgrade_module_1_25_0($module)
{
    $db_changes = [
        'cart_bpost' => [
            'add' => 'delivery_codes',
            'type' => 'varchar(50) NOT NULL',
            'def' => 'DEFAULT "0,0,0"',
            'after' => 'option_kmi',
        ],
        'order_bpost' => [
            'add' => 'dt_drop',
            'type' => 'int(10) unsigned NOT NULL',
            'def' => 'DEFAULT 0',
            'after' => 'shm',
        ],
    ];

    $ret = true;
    foreach ($db_changes as $table => $details) {
        $sql_exists = sprintf('SHOW COLUMNS FROM `%s` LIKE "%s";', _DB_PREFIX_ . $table, $details['add']);

        if (!Db::getInstance()->executeS($sql_exists)) {
            $sql = sprintf('
                    ALTER TABLE `%s`
                    ADD COLUMN `%s` %s %s AFTER `%s`;
                ',
                _DB_PREFIX_ . $table,
                $details['add'],
                $details['type'],
                $details['def'],
                $details['after']
            );
            $ret &= Db::getInstance()->execute($sql);
        }
    }

    $ret &= FileUpgrader::removeAll([
        '/controllers/front/lightbox.php',
        '/controllers/front/lightbox14.php',
        '/controllers/front/servicepoint.php',
        '/views/css/lightbox.css',
        '/views/css/lightbox.scss',
        '/views/js/bpostshm.js',
        '/views/js/input-options.min.js',
        '/views/js/srgdebug.js',
        '/views/templates/admin/orders_bpost/helpers/list/list_footer14.tpl',
        '/views/templates/front/lightbox-at-247.tpl',
        '/views/templates/front/lightbox-point-list.tpl',
        '/views/templates/hook/extra-carrier.tpl',
    ]);

    return (bool) $ret;
}
