<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

use PrestaShop\Module\BpostShm\Utils\FileUpgrader;
use PrestaShop\Module\BpostShm\Utils\Installer;

if (!defined('_PS_VERSION_')) {
    exit;
}

/**
 * Upgrade old module 1.* to PS 8 new module
 *
 * @param $module
 *
 * @return bool
 */
function upgrade_module_2_0_0($module): bool
{
    // unregister all hooks
    $sql = 'SELECT DISTINCT(`id_hook`) FROM `' . _DB_PREFIX_ . 'hook_module` WHERE `id_module` = ' . (int) $module->id;
    $result = Db::getInstance()->executeS($sql);
    foreach ($result as $row) {
        // Unhook this module from each of the hooks
        $module->unregisterHook((int) $row['id_hook']);
        // Remove all hook conditions that may have been configured - don't confuse it with error exception. :-)
        $module->unregisterExceptions((int) $row['id_hook']);
    }

    // register hooks
    $module->registerHook($module->getHookDispatcher()->getAvailableHooks());

    // Remove obsolete files
    FileUpgrader::removeAll([
        '/backward_compatibility',
        '/classes',
        '/controllers/admin',
        '/controllers/front/bpostbase.php',
        '/controllers/front/CarrierBoxService.php',
        '/controllers/front/carrierbox.php',
        '/controllers/front/clientbpost.php',
        '/controllers/front/clientbpost14.php',
        '/controllers/front/enabledcountries.php',
        '/controllers/front/EnabledCountriesService.php',
        '/controllers/front/FrontControllerService.php',
        '/controllers/front/servicepoints.php',
        '/controllers/front/ServicePointService.php',
        '/controllers/front/webservicextra.php',
        '/log',
        '/mails',
        '/translations/en.php',
        '/translations/fr.php',
        '/translations/nl.php',
        '/translations/index.php',
        '/upgrade/install-1.21.0.php',
        '/upgrade/install-1.22.0.php',
        '/upgrade/install-1.25.0.php',
        '/upgrade/install-1.30.0.php',
        '/upgrade/install-1.30.4.php',
        '/upgrade/install-1.36.0.php',
        '/upgrade/install-1.40.0.php',
        '/upgrade/install-1.60.0.php',
        '/upgrade/install-1.63.0.php',
        '/upgrade/install-1.64.0.php',
        '/upgrade/install-1.64.2.php',
        '/upgrade/install-1.65.0.php',
        '/upgrade/install-1.65.2.php',
        '/upgrade/install-1.65.4.php',
        '/views/css/admin14.css',
        '/views/css/admin-bpost.css',
        '/views/css/admin-bpost.scss',
        '/views/css/carrier-box.css',
        '/views/css/global1616.css',
        '/views/css/global1616.min.css',
        '/views/css/jquery.qtip.min.css',
        '/views/css/lightbox.css',
        '/views/css/lightbox.scss',
        '/views/css/servicepoint.css',
        '/views/css/servicepoint.scss',
        '/views/img',
        '/views/js',
        '/views/templates/front/order_details.tpl',
        '/views/templates/admin/blurb',
        '/views/templates/admin/orders_bpost',
        '/views/templates/admin/settings/blurb',
        '/views/templates/admin/settings/tabs',
        '/views/templates/admin/settings/settings.tpl',
        '/views/templates/admin/admin_order_details.tpl',
        '/views/templates/front',
        '/views/templates/hook/adminordersbpost-header.tpl',
        '/views/templates/hook/back-office-header.tpl',
        '/views/templates/hook/before-carrier.tpl',
        '/views/templates/hook/debug-bc.tpl',
        '/views/templates/hook/order_details.tpl',
        '/views/templates/hook/footer.tpl',
        '/AdminOrdersBpost.php',
        '/cron.php',
        '/en.php',
        '/fr.php',
        '/nl.php',
        '/logo.gif',
    ]);
    FileUpgrader::backupDir(_PS_OVERRIDE_DIR_ . 'modules/bpostshm');
    FileUpgrader::backupDir(_PS_THEME_DIR_ . 'modules/bpostshm');

    (new Installer($module))->upgradeV2();

    return true;
}
